.. include:: ../../README.rst

Developer documentation
========================

.. toctree::
   :maxdepth: 3

   object_model.rst

.. only:: html

   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
